var nats_8h =
[
    [ "jsOptions::jsOptionsPublishAsync", "structjs_options_1_1js_options_publish_async.html", "structjs_options_1_1js_options_publish_async" ],
    [ "jsOptions::jsOptionsStream", "structjs_options_1_1js_options_stream.html", "structjs_options_1_1js_options_stream" ],
    [ "jsOptions::jsOptionsStream::jsOptionsStreamPurge", "structjs_options_1_1js_options_stream_1_1js_options_stream_purge.html", "structjs_options_1_1js_options_stream_1_1js_options_stream_purge" ],
    [ "jsOptions::jsOptionsStream::jsOptionsStreamInfo", "structjs_options_1_1js_options_stream_1_1js_options_stream_info.html", "structjs_options_1_1js_options_stream_1_1js_options_stream_info" ],
    [ "NATS_EXTERN", "nats_8h.html#a3bc1b3fe7f64083e60c7c3b93f205bad", null ],
    [ "NATS_DEFAULT_URL", "nats_8h.html#a911c54900b46b968205871cd9f68d36c", null ],
    [ "JSMsgSize", "nats_8h.html#a5ce9005964bd9cf0604a9ef1afa87ea4", null ],
    [ "JSMsgRollup", "nats_8h.html#a3938efee417dc67ff2bcf62f913f9054", null ],
    [ "JSMsgRollupSubject", "nats_8h.html#ad22dce8f66bae9b3e1027790d9c95c09", null ],
    [ "JSMsgRollupAll", "nats_8h.html#acc62d11b7e67fe3feb74acdfa4a6e8ac", null ],
    [ "JSStream", "nats_8h.html#aa2f2c14de864839a2ff7ea34415d37e0", null ],
    [ "JSSequence", "nats_8h.html#a1c0a11996b44abc16a4f444ee4c1cb94", null ],
    [ "JSLastSequence", "nats_8h.html#ae18fb15ea8130a650e904e5153eb30d5", null ],
    [ "JSTimeStamp", "nats_8h.html#a5525cb01f8b0aec73cb13f3276449e0e", null ],
    [ "JSSubject", "nats_8h.html#a3776aa9985557f0c6e382b01d2e3f602", null ],
    [ "natsSock", "nats_8h.html#af798865ac824e5959987de0fe8d07383", null ],
    [ "natsConnection", "group__types_group.html#gaf88dca0a18efb5c5e994d265a9f04aec", null ],
    [ "natsStatistics", "group__types_group.html#ga57a4b8c7109e2773878655722ce028aa", null ],
    [ "natsSubscription", "group__types_group.html#ga87158ec63b4f90f69e20451624ea01d8", null ],
    [ "natsMsg", "group__types_group.html#gadcab54026c4ed78f344ce03ce31bb61a", null ],
    [ "natsOptions", "group__types_group.html#gabcc48b40a81fe302188f4ee06ea9c54e", null ],
    [ "natsInbox", "group__types_group.html#ga206c3d4d6f4f6f96fd2cae53a3df31c1", null ],
    [ "natsMsgList", "group__types_group.html#gafd5523161ec3783e79719cb9a9a66b5b", null ],
    [ "jsCtx", "group__types_group.html#gaaf12cdd24c6cc23a57c20466c92ff8c1", null ],
    [ "jsPubOptions", "group__types_group.html#ga7bbea3575d35dcdbfc9b766b04269eb7", null ],
    [ "jsPlacement", "group__types_group.html#ga49d1138fac9da8b85d00a367081e91c9", null ],
    [ "jsExternalStream", "group__types_group.html#gaef6601477f6456bebc229f7f38982a6c", null ],
    [ "jsStreamSource", "group__types_group.html#gab4c43c87d81917aab748a50eee028449", null ],
    [ "jsRePublish", "group__types_group.html#gab991313d33ce270a882e4d0756c138f6", null ],
    [ "jsStreamConfig", "group__types_group.html#ga26fd6a73df327ca3c271e46ddefc8acf", null ],
    [ "jsLostStreamData", "group__types_group.html#gaf80828510450faf84bbf456e94f5b784", null ],
    [ "jsStreamStateSubject", "group__types_group.html#ga55dce2fa9ecd215716cc9ceece7dfefa", null ],
    [ "jsStreamStateSubjects", "group__types_group.html#gae8b57d9c40364f97a705f3e61a1156b0", null ],
    [ "jsStreamState", "group__types_group.html#ga2bfd6de6ffc84d767482b3dd57cb9271", null ],
    [ "jsPeerInfo", "group__types_group.html#ga1e938dab794089f9329d7b7ece8f3e9b", null ],
    [ "jsClusterInfo", "group__types_group.html#gaaf92318ce94a1ae3547c9a7af5a3f4f6", null ],
    [ "jsStreamSourceInfo", "group__types_group.html#gab2f33f57188a550f2f747d4f27bc24bd", null ],
    [ "jsStreamInfo", "group__types_group.html#ga2629c9454996edf7914be36a9e44921b", null ],
    [ "jsStreamInfoList", "group__types_group.html#ga1e54c2a1bc94834d1670875fc151f565", null ],
    [ "jsStreamNamesList", "group__types_group.html#gaf4d31a4dc83b2805422beafb1f8fa000", null ],
    [ "jsConsumerConfig", "group__types_group.html#ga0483b2197c0ddd9082b48c2dd3fe7cee", null ],
    [ "jsConsumerSequenceMismatch", "group__types_group.html#gace471cd2cef1df797b2a1c6b485049bd", null ],
    [ "jsSubOptions", "group__types_group.html#gaccfaac2079656ffd40d003e4de5d2280", null ],
    [ "jsSequencePair", "group__types_group.html#ga39011d30b295759b7f6ca0a7539dff8f", null ],
    [ "jsSequenceInfo", "group__types_group.html#ga27e1a5d5b513f9eb7d61a17db71f8003", null ],
    [ "jsConsumerInfo", "group__types_group.html#ga2f21bb79884e56a5613d7fe76b11b1e5", null ],
    [ "jsConsumerInfoList", "group__types_group.html#gadad3bf72baae970662248d82d9b05d0a", null ],
    [ "jsConsumerNamesList", "group__types_group.html#gad00ab4381eec504ada3272aa9ff8adb2", null ],
    [ "jsAPIStats", "group__types_group.html#gad057a0107367ce5727975f3daf63ff75", null ],
    [ "jsAccountLimits", "group__types_group.html#gaa889f706cce285adb9cea8aba0b76866", null ],
    [ "jsTier", "group__types_group.html#ga1d48d3eb36b50c9ab6d8477dccf247d8", null ],
    [ "jsAccountInfo", "group__types_group.html#ga57cdc53b29a4fedb5a4140b6e64a4fab", null ],
    [ "jsMsgMetaData", "group__types_group.html#gace9595b1a5ce3f7a13670367fd293b4a", null ],
    [ "jsPubAck", "group__types_group.html#gaf1d5e436c5d41c5b9b96d84e3d2bc86f", null ],
    [ "jsPubAckErr", "group__types_group.html#gadb7c287bc86b92765fbe45a066b96f40", null ],
    [ "jsDirectGetMsgOptions", "group__types_group.html#ga85123afa00d522a249a5b2a8abd7e063", null ],
    [ "jsFetchRequest", "group__types_group.html#gaf11e6664c1f335a5287af71c703935fa", null ],
    [ "jsOptions", "group__types_group.html#ga0e3a3b7cf89e7dfa955f0f8f3f1eb6e5", null ],
    [ "kvStore", "group__types_group.html#ga054c05493dd3cfc5c3e7a665a424e54a", null ],
    [ "kvEntry", "group__types_group.html#gad489fb4074f27427560ca71797db6191", null ],
    [ "kvStatus", "group__types_group.html#gad3a0dd2dac950d5709ee5772b104fc80", null ],
    [ "kvWatcher", "group__types_group.html#ga526fa6d37e818784b94cdc1713f3a043", null ],
    [ "kvConfig", "group__types_group.html#ga6d594b091b4bb46192336413066a8edf", null ],
    [ "kvWatchOptions", "group__types_group.html#gac32f992fe797a1f7befc7dc3452640b6", null ],
    [ "kvPurgeOptions", "group__types_group.html#ga90e8de23c4468005488bde690a2ffe9d", null ],
    [ "kvEntryList", "group__types_group.html#ga0125d394a3cbae2a1713eed8fab7f78e", null ],
    [ "kvKeysList", "group__types_group.html#gab36492d9d4370337cfed80edce4144e0", null ],
    [ "stanConnection", "group__types_group.html#ga9e826493769d23086cfccefe95cdf64c", null ],
    [ "stanSubscription", "group__types_group.html#gae4dae869fb614536f0f027c2e2660cc5", null ],
    [ "stanMsg", "group__types_group.html#ga2cf5db7703b42d97abe56a3e83b2a87d", null ],
    [ "stanConnOptions", "group__types_group.html#ga13d64411878ba13a6ca39c915f2447c1", null ],
    [ "stanSubOptions", "group__types_group.html#ga023712711f5c289663fc2223e83686d3", null ],
    [ "natsMsgHandler", "group__callbacks_group.html#gad1a5ac566893e13dc8c81ac0e9c87afe", null ],
    [ "natsConnectionHandler", "group__callbacks_group.html#gacdef6aff3e47953f19e35857ab8e274c", null ],
    [ "natsErrHandler", "group__callbacks_group.html#ga9e511dffa471dfb971b7dd2b12329626", null ],
    [ "natsEvLoop_Attach", "group__callbacks_group.html#ga245eab0a01a485e40fba267f84ec037f", null ],
    [ "natsEvLoop_ReadAddRemove", "group__callbacks_group.html#gaea4c125ecfb43eaf43da20e8444c2aaa", null ],
    [ "natsEvLoop_WriteAddRemove", "group__callbacks_group.html#ga2bb5dd2d821ca5bbc0488f7e6aceed17", null ],
    [ "natsEvLoop_Detach", "group__callbacks_group.html#gab63dee7f7012ba11ae20b76dbc36f2d0", null ],
    [ "natsUserJWTHandler", "group__callbacks_group.html#ga258b30458134be90f17315c037f34b7b", null ],
    [ "natsSignatureHandler", "group__callbacks_group.html#gab786ffd670c86de0563559351305080b", null ],
    [ "natsTokenHandler", "group__callbacks_group.html#ga4b02de70fe9380d184fd01d87527f499", null ],
    [ "natsOnCompleteCB", "group__callbacks_group.html#ga245131e64f1d0dff7edc8ed874a07e9a", null ],
    [ "natsCustomReconnectDelayHandler", "group__callbacks_group.html#ga3353d4b92851c52121f65aaf0684cba4", null ],
    [ "jsPubAckErrHandler", "group__callbacks_group.html#ga954768cc1d3388bb6ab723e777647992", null ],
    [ "jsPubAckHandler", "group__callbacks_group.html#ga4f66e065bd918f02510d4c53d8a5b729", null ],
    [ "stanPubAckHandler", "group__callbacks_group.html#gad5d6a685731b3bf635995b7375af4d18", null ],
    [ "stanMsgHandler", "group__callbacks_group.html#gaf7456e37fa14f1834d9048d3789e9409", null ],
    [ "stanConnectionLostHandler", "group__callbacks_group.html#gac34092f6c698374f86ad349302bdd55c", null ],
    [ "jsRetentionPolicy", "group__types_group.html#ga410f8fb053efa02b2ca1de0c02fa4b6d", [
      [ "js_LimitsPolicy", "group__types_group.html#gga410f8fb053efa02b2ca1de0c02fa4b6da6a2aa02f32acec6526d81f6e974e690f", null ],
      [ "js_InterestPolicy", "group__types_group.html#gga410f8fb053efa02b2ca1de0c02fa4b6dae874de4a787cfbec4c6d0eb1a3f05ebd", null ],
      [ "js_WorkQueuePolicy", "group__types_group.html#gga410f8fb053efa02b2ca1de0c02fa4b6daf7e6581e69572691b01d1294a3c3a478", null ]
    ] ],
    [ "jsDiscardPolicy", "group__types_group.html#ga7f88b7d482488398074f9d1419a9b8c2", [
      [ "js_DiscardOld", "group__types_group.html#gga7f88b7d482488398074f9d1419a9b8c2abb31b828421634f1e6a1ef9359bc91f6", null ],
      [ "js_DiscardNew", "group__types_group.html#gga7f88b7d482488398074f9d1419a9b8c2a99d7f2d740af26c340c0a4e2b72fb6ab", null ]
    ] ],
    [ "jsStorageType", "group__types_group.html#ga1802a53c79e667f093bba033b16adc98", [
      [ "js_FileStorage", "group__types_group.html#gga1802a53c79e667f093bba033b16adc98a1d9dad1854cf374b22e3688b98284dec", null ],
      [ "js_MemoryStorage", "group__types_group.html#gga1802a53c79e667f093bba033b16adc98a428ed10448726ad01c1db77a7f748314", null ]
    ] ],
    [ "jsDeliverPolicy", "group__types_group.html#ga117ed2c35f89ef3144540ed9cbadc818", [
      [ "js_DeliverAll", "group__types_group.html#gga117ed2c35f89ef3144540ed9cbadc818ac692ba1363103768ac4bb58695549758", null ],
      [ "js_DeliverLast", "group__types_group.html#gga117ed2c35f89ef3144540ed9cbadc818abbd81d6c4e0f17f30e2186f1335e991d", null ],
      [ "js_DeliverNew", "group__types_group.html#gga117ed2c35f89ef3144540ed9cbadc818a82b8d36e17391212398984f92db9c381", null ],
      [ "js_DeliverByStartSequence", "group__types_group.html#gga117ed2c35f89ef3144540ed9cbadc818a06299d9c8262a16306ba6cc16d293c5e", null ],
      [ "js_DeliverByStartTime", "group__types_group.html#gga117ed2c35f89ef3144540ed9cbadc818a33317133d42f21bf5919827a691543f6", null ],
      [ "js_DeliverLastPerSubject", "group__types_group.html#gga117ed2c35f89ef3144540ed9cbadc818abb50ebcd2fbafe27038c966121b9407b", null ]
    ] ],
    [ "jsAckPolicy", "group__types_group.html#ga8fcb50e6e7312834791f9e237d28e873", [
      [ "js_AckExplicit", "group__types_group.html#gga8fcb50e6e7312834791f9e237d28e873a02d46a6395933c55c95ee5194bb6b80e", null ],
      [ "js_AckNone", "group__types_group.html#gga8fcb50e6e7312834791f9e237d28e873afd91fe31cf57c68863ca3090b07c296c", null ],
      [ "js_AckAll", "group__types_group.html#gga8fcb50e6e7312834791f9e237d28e873a1232af28bf4e4b82e962174f1432ed4a", null ]
    ] ],
    [ "jsReplayPolicy", "group__types_group.html#ga8650faf52b0b6b23df376eebeb9d0354", [
      [ "js_ReplayInstant", "group__types_group.html#gga8650faf52b0b6b23df376eebeb9d0354a2c4a1e2b75f31dd69a89b541d75afa44", null ],
      [ "js_ReplayOriginal", "group__types_group.html#gga8650faf52b0b6b23df376eebeb9d0354a6ee3851dac5c90a61492193dd55931f5", null ]
    ] ],
    [ "kvOperation", "group__types_group.html#ga89db3bd6bf11af3ac5eb3ab560d16332", [
      [ "kvOp_Unknown", "group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332a0b7a6bef67e4220f5f0c4075f2ed16b6", null ],
      [ "kvOp_Put", "group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332acc0e1da3c292cb7eb19d909c9dfd788a", null ],
      [ "kvOp_Delete", "group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332a4efb91331f3307128c75af5b23362f83", null ],
      [ "kvOp_Purge", "group__types_group.html#gga89db3bd6bf11af3ac5eb3ab560d16332aee19ab8144bf518e251ea2004309b657", null ]
    ] ],
    [ "nats_Open", "group__library_group.html#ga4a26d4caecb23348f6eee862c95fee7d", null ],
    [ "nats_GetVersion", "group__library_group.html#ga0d8c3df1c0c4a3d340d8ff81355fb1e8", null ],
    [ "nats_GetVersionNumber", "group__library_group.html#ga5fbbaa19b0290b654d2669a05bd512e8", null ],
    [ "nats_CheckCompatibility", "group__library_group.html#ga8c2ad4df801bd9d11564587ed3a7081e", null ],
    [ "nats_Now", "group__library_group.html#gaa3c10ba3ae001595007ad0dc5dccc15e", null ],
    [ "nats_NowInNanoSeconds", "group__library_group.html#gacf5e423920d6a647df3bbf7de39d5223", null ],
    [ "nats_Sleep", "group__library_group.html#gad5040264cd4b1404956babf3c03a4f09", null ],
    [ "nats_GetLastError", "group__library_group.html#gadecfd49a58b581dbba40da77b195fd85", null ],
    [ "nats_GetLastErrorStack", "group__library_group.html#gaca24172e1b97ca01cee29ca437f5702e", null ],
    [ "nats_PrintLastErrorStack", "group__library_group.html#ga5fab3b18c4fe3630254483575f6066f4", null ],
    [ "nats_SetMessageDeliveryPoolSize", "group__library_group.html#gab21e94ce7a7d226611ea2c05914cf19d", null ],
    [ "nats_ReleaseThreadMemory", "group__library_group.html#gafe171baefa00a85b77205116e9f3e48a", null ],
    [ "nats_Sign", "group__library_group.html#gaf781f246e2e0ab24623ca667c48dc3ba", null ],
    [ "nats_Close", "group__library_group.html#gae75131e0ce4e5b89d0f82ea7892f112e", null ],
    [ "nats_CloseAndWait", "group__library_group.html#gaf75bb5b38bf32e6a8f43e54068625903", null ],
    [ "natsStatus_GetText", "group__status_group.html#ga4a83c4a08f1e4dd9451c1a88b6a4254e", null ],
    [ "natsStatistics_Create", "group__stats_group.html#gafa923df029168f4991b77ffdd9e24877", null ],
    [ "natsStatistics_GetCounts", "group__stats_group.html#gad85f5ffb4272713f6cc6d988e6d4e75f", null ],
    [ "natsStatistics_Destroy", "group__stats_group.html#ga26a04e77af8fc160adf7c33088dcf59c", null ],
    [ "natsOptions_Create", "group__opts_group.html#ga61d4a0cf2fbf7d13cc910e5a00c575be", null ],
    [ "natsOptions_SetURL", "group__opts_group.html#ga3f7e760214417c7d87541ecb9ab5bea5", null ],
    [ "natsOptions_SetServers", "group__opts_group.html#gacb7e964ae54b74d972d72e118b7b8bdf", null ],
    [ "natsOptions_SetUserInfo", "group__opts_group.html#ga5b99da7dd74aac3be962f323c3863d9e", null ],
    [ "natsOptions_SetToken", "group__opts_group.html#gad58a5b9dabadeebda30e952ff7b39193", null ],
    [ "natsOptions_SetTokenHandler", "group__opts_group.html#ga23a3b1f022112e98ddccb18b247b4426", null ],
    [ "natsOptions_SetNoRandomize", "group__opts_group.html#gaabf8763b931dcf389c83fd95d760a413", null ],
    [ "natsOptions_SetTimeout", "group__opts_group.html#ga17cd7fe41176cd98aca1184fa9352ad9", null ],
    [ "natsOptions_SetName", "group__opts_group.html#ga1c529d347be0fe2eec17c7f4698e283e", null ],
    [ "natsOptions_SetSecure", "group__opts_group.html#gaa1f09416d443fa7a6af6b695da563eba", null ],
    [ "natsOptions_LoadCATrustedCertificates", "group__opts_group.html#ga2cd6563694a439b3949a31fd81103099", null ],
    [ "natsOptions_SetCATrustedCertificates", "group__opts_group.html#gafb30794fc2ae74b9e0bd8fb609b901c8", null ],
    [ "natsOptions_LoadCertificatesChain", "group__opts_group.html#ga36943e2ba53d05407cdabc4e7e96484b", null ],
    [ "natsOptions_SetCertificatesChain", "group__opts_group.html#gae98f0f9034e93941767ab1ae6eec2c0c", null ],
    [ "natsOptions_SetCiphers", "group__opts_group.html#ga5698f020e8eb3e7440eb073fe08ef62c", null ],
    [ "natsOptions_SetCipherSuites", "group__opts_group.html#ga2b7f144b011d8ce62941b608a8f324f0", null ],
    [ "natsOptions_SetExpectedHostname", "group__opts_group.html#ga0ba43ba9930df385e4781b12be9f2851", null ],
    [ "natsOptions_SkipServerVerification", "group__opts_group.html#ga6f804ec44adc299989fe623570679da3", null ],
    [ "natsOptions_SetVerbose", "group__opts_group.html#gaa16bfd09ef318af18c27a0e199681b69", null ],
    [ "natsOptions_SetPedantic", "group__opts_group.html#ga26f166af20de98bec67bc6cc916f769e", null ],
    [ "natsOptions_SetPingInterval", "group__opts_group.html#gae68fb615835364c0809555e8dc93f57e", null ],
    [ "natsOptions_SetMaxPingsOut", "group__opts_group.html#gaaff89c3f41627f4b2929dbc9b82d265b", null ],
    [ "natsOptions_SetIOBufSize", "group__opts_group.html#ga1a3e3abfd7ddd8aff247df8f332bbda3", null ],
    [ "natsOptions_SetAllowReconnect", "group__opts_group.html#ga3d1d3cb2f2a0e23d27dd60e96d1cc91b", null ],
    [ "natsOptions_SetMaxReconnect", "group__opts_group.html#gab54cd2719c0b64eebd6c7b83dd2908a0", null ],
    [ "natsOptions_SetReconnectWait", "group__opts_group.html#ga2730f4e16e318a2ef8de98dbf6ede807", null ],
    [ "natsOptions_SetReconnectJitter", "group__opts_group.html#ga8f3df57ed8ae418d3ae6678ae5e2a5d2", null ],
    [ "natsOptions_SetCustomReconnectDelay", "group__opts_group.html#ga3593165aa113d6736e0226ddc56b3e9d", null ],
    [ "natsOptions_SetReconnectBufSize", "group__opts_group.html#gaa0d4b7ece8477cb9879f0dafff3456a5", null ],
    [ "natsOptions_SetMaxPendingMsgs", "group__opts_group.html#ga95510436eee06f9992ded96a44795c40", null ],
    [ "natsOptions_SetErrorHandler", "group__opts_group.html#ga127ec7a8196b453947a7fa9a64096cbd", null ],
    [ "natsOptions_SetClosedCB", "group__opts_group.html#ga44410242e73134e5bb51ef27904a9253", null ],
    [ "natsOptions_SetDisconnectedCB", "group__opts_group.html#gadc8dc0cedd91bda71d544f3dedc4a039", null ],
    [ "natsOptions_SetReconnectedCB", "group__opts_group.html#ga26a48c8529fffa5f5d1a61c030979980", null ],
    [ "natsOptions_SetDiscoveredServersCB", "group__opts_group.html#gab5baab507c974402ab0d8c5e8227ee65", null ],
    [ "natsOptions_SetIgnoreDiscoveredServers", "group__opts_group.html#ga7e4172084520708b8c9f28e73174461c", null ],
    [ "natsOptions_SetLameDuckModeCB", "group__opts_group.html#ga54dea2ffeb33779771652a7a14fc4adc", null ],
    [ "natsOptions_SetEventLoop", "group__opts_group.html#gab09491bad908dedcb323c780280733ff", null ],
    [ "natsOptions_UseGlobalMessageDelivery", "group__opts_group.html#gabf060c92648b50c069f0abe7cbb06f1c", null ],
    [ "natsOptions_IPResolutionOrder", "group__opts_group.html#ga7ca713c7532eff4d41a492e95b8822cf", null ],
    [ "natsOptions_SetSendAsap", "group__opts_group.html#ga8f06568cc3319a5a0eef9f80282034ca", null ],
    [ "natsOptions_UseOldRequestStyle", "group__opts_group.html#ga70aa85319933d78c0076cc862fa3e5a6", null ],
    [ "natsOptions_SetFailRequestsOnDisconnect", "group__opts_group.html#gadef4376a5e608cbc8c1a9e2b6335dc79", null ],
    [ "natsOptions_SetNoEcho", "group__opts_group.html#ga4f694b87039cedaa65cd25656b14d1a3", null ],
    [ "natsOptions_SetRetryOnFailedConnect", "group__opts_group.html#ga20946800d024b7089e73d63454d1c19f", null ],
    [ "natsOptions_SetUserCredentialsCallbacks", "group__opts_group.html#ga60117450fc1f7b6f81bab455aeed7515", null ],
    [ "natsOptions_SetUserCredentialsFromFiles", "group__opts_group.html#ga59b47f7b7a19085cf8eaada9bfe5606e", null ],
    [ "natsOptions_SetNKey", "group__opts_group.html#ga0290eac4665569c850468d9f00e246a0", null ],
    [ "natsOptions_SetNKeyFromSeed", "group__opts_group.html#ga696f02e0493c00d3c1eafff45b62b68e", null ],
    [ "natsOptions_SetWriteDeadline", "group__opts_group.html#gaafda5fb8d9ee3a17bd475ceaecfac218", null ],
    [ "natsOptions_DisableNoResponders", "group__opts_group.html#ga192465163abb87ad48a843b45cdf9984", null ],
    [ "natsOptions_SetCustomInboxPrefix", "group__opts_group.html#gac5173473a731a4a36d15346fedddf91f", null ],
    [ "natsOptions_Destroy", "group__opts_group.html#ga93d8068cd6fff53b7f8e1c403db45eb9", null ],
    [ "stanConnOptions_Create", "group__stan_conn_opts_group.html#gaff52a1ce90253b4bdbb0005fca4f71b6", null ],
    [ "stanConnOptions_SetURL", "group__stan_conn_opts_group.html#ga3c6d511fc1e1febcdf5344960de5a0b3", null ],
    [ "stanConnOptions_SetNATSOptions", "group__stan_conn_opts_group.html#gae3fc9a4daa7f85367811a313857337b4", null ],
    [ "stanConnOptions_SetConnectionWait", "group__stan_conn_opts_group.html#ga66c72c482696d9ceca71fced7cbb1264", null ],
    [ "stanConnOptions_SetPubAckWait", "group__stan_conn_opts_group.html#ga36f2ee441562dcf619d6e020b823fc96", null ],
    [ "stanConnOptions_SetDiscoveryPrefix", "group__stan_conn_opts_group.html#ga07105d1d00878bba19f47243b2c88402", null ],
    [ "stanConnOptions_SetMaxPubAcksInflight", "group__stan_conn_opts_group.html#ga29eee1be7eff749aeac3bab60d1b0405", null ],
    [ "stanConnOptions_SetPings", "group__stan_conn_opts_group.html#gad835223f08fbeae2a3c7a34d3fa1550b", null ],
    [ "stanConnOptions_SetConnectionLostHandler", "group__stan_conn_opts_group.html#ga19ba15c8001aa835b261eea3a309e6d3", null ],
    [ "stanConnOptions_Destroy", "group__stan_conn_opts_group.html#ga83fd0a29b136cbfb643be642eb2fa726", null ],
    [ "stanSubOptions_Create", "group__stan_sub_opts_group.html#gad87a2cef4f4ddf64696f9864773c37cf", null ],
    [ "stanSubOptions_SetDurableName", "group__stan_sub_opts_group.html#gaa018bceba99ef3726157e87c6918ab14", null ],
    [ "stanSubOptions_SetAckWait", "group__stan_sub_opts_group.html#gafbb4e6c74978c4e8f30f016c20cc2bdf", null ],
    [ "stanSubOptions_SetMaxInflight", "group__stan_sub_opts_group.html#ga35efbdea888e00440c500845064931c0", null ],
    [ "stanSubOptions_StartAtSequence", "group__stan_sub_opts_group.html#ga6cb7f6e1ac697d16959f9042eeb84dc1", null ],
    [ "stanSubOptions_StartAtTime", "group__stan_sub_opts_group.html#gaafd7a553486eea3c9d309da0744a3608", null ],
    [ "stanSubOptions_StartAtTimeDelta", "group__stan_sub_opts_group.html#ga27d9175901997b8468997019746599b5", null ],
    [ "stanSubOptions_StartWithLastReceived", "group__stan_sub_opts_group.html#ga856a74e31f3307faf988747c1f88717c", null ],
    [ "stanSubOptions_DeliverAllAvailable", "group__stan_sub_opts_group.html#gab09b81358e93199a4631eb06f1ec179f", null ],
    [ "stanSubOptions_SetManualAckMode", "group__stan_sub_opts_group.html#ga6f49ae2629e49d2bfa35990cf030bf83", null ],
    [ "stanSubOptions_Destroy", "group__stan_sub_opts_group.html#ga1b56877d0a6729e148c9c288e2b88e3f", null ],
    [ "natsInbox_Create", "group__inbox_group.html#gaa1ec779a0b7ead54b78da05533848b6d", null ],
    [ "natsInbox_Destroy", "group__inbox_group.html#gabd6444fb8f28afb9c2b6645945f46cfe", null ],
    [ "natsMsgList_Destroy", "group__msg_group.html#ga1a091d24f939d881bf04fba78b8995c2", null ],
    [ "natsMsg_Create", "group__msg_group.html#ga098e4fec1c5a71c00a0d092fbd6d1a21", null ],
    [ "natsMsg_GetSubject", "group__msg_group.html#gad7cad38946648e3047aa0665a3dd230a", null ],
    [ "natsMsg_GetReply", "group__msg_group.html#ga880535362c91b3e405792aa66ff945b6", null ],
    [ "natsMsg_GetData", "group__msg_group.html#ga523364451fd92534e754054266196e59", null ],
    [ "natsMsg_GetDataLength", "group__msg_group.html#ga25b69066ae50287e178aaf4f70f7d3de", null ],
    [ "natsMsgHeader_Set", "group__msg_group.html#gaf30b47d4217c9335919f05536e379af8", null ],
    [ "natsMsgHeader_Add", "group__msg_group.html#ga2b641ec3b1745604d7de1102e472254b", null ],
    [ "natsMsgHeader_Get", "group__msg_group.html#gab3349f0b0ce721b340d5c0753c90ee18", null ],
    [ "natsMsgHeader_Values", "group__msg_group.html#gae1ce9c9d82d151a3ea9dc03da048f66f", null ],
    [ "natsMsgHeader_Keys", "group__msg_group.html#ga6ee8a007111ada293dd24ff0bab02491", null ],
    [ "natsMsgHeader_Delete", "group__msg_group.html#gac78ca02dc93d05cae837ced6386408f1", null ],
    [ "natsMsg_IsNoResponders", "group__msg_group.html#ga43aa4a8e4b93725b4876ee2677e19c7b", null ],
    [ "natsMsg_Destroy", "group__msg_group.html#ga9e9590018284939f43f60964283f33ae", null ],
    [ "stanMsg_GetSequence", "group__stan_msg_group.html#ga98b66ff73447e1d7e329edbfcde782b5", null ],
    [ "stanMsg_GetTimestamp", "group__stan_msg_group.html#ga2fa524b11e9621cf46ca9b1a3ca66452", null ],
    [ "stanMsg_IsRedelivered", "group__stan_msg_group.html#ga8e537d014b89d9d7da7906b2ee75d5c0", null ],
    [ "stanMsg_GetData", "group__stan_msg_group.html#ga2f27fbfb79a46c52e079f670c59e1260", null ],
    [ "stanMsg_GetDataLength", "group__stan_msg_group.html#ga7d1e394a686bc25ab7376b7f28b9e777", null ],
    [ "stanMsg_Destroy", "group__stan_msg_group.html#gacd0059fb499963f5b2eae18053e5f74f", null ],
    [ "natsConnection_Connect", "group__conn_mgt_group.html#ga740be1ba16a8570eb98ef6755ebf52ce", null ],
    [ "natsConnection_ProcessReadEvent", "group__conn_mgt_group.html#gaa89c06e30e19ff361125bfc9114d89a8", null ],
    [ "natsConnection_ProcessWriteEvent", "group__conn_mgt_group.html#gad81b603b84c0180aefc6d5ebad7f2a47", null ],
    [ "natsConnection_ConnectTo", "group__conn_mgt_group.html#gafb83c8d7970ba68be0e6c40c38cdfde4", null ],
    [ "natsConnection_IsClosed", "group__conn_mgt_group.html#ga530f0f1c75c58a81aae1a59f15b46d9f", null ],
    [ "natsConnection_IsReconnecting", "group__conn_mgt_group.html#ga5aa349fc3895dde772671b324b07a688", null ],
    [ "natsConnection_IsDraining", "group__conn_mgt_group.html#ga15a0f8aa9a6f621535d01593a4c8edd5", null ],
    [ "natsConnection_Status", "group__conn_mgt_group.html#ga33fa209522e5e0226b5b7c7d720a3b98", null ],
    [ "natsConnection_Buffered", "group__conn_mgt_group.html#ga0433159e518540ff874c4026fe9cd0c5", null ],
    [ "natsConnection_Flush", "group__conn_mgt_group.html#ga1c98f8d89bb8e20ea8621e860a90267f", null ],
    [ "natsConnection_FlushTimeout", "group__conn_mgt_group.html#ga85915ef0c8b87993be1b076099d6a7c1", null ],
    [ "natsConnection_GetMaxPayload", "group__conn_mgt_group.html#ga68e7149f7ff1cc4989b3f795fa7e76d9", null ],
    [ "natsConnection_GetStats", "group__conn_mgt_group.html#ga68821a8ae1176096b5afef7fdc7947ec", null ],
    [ "natsConnection_GetConnectedUrl", "group__conn_mgt_group.html#gaf623280407c43ade02285005f0642e6d", null ],
    [ "natsConnection_GetConnectedServerId", "group__conn_mgt_group.html#ga48cee9ea1cdc9fc2770de2f9f0fd1ccf", null ],
    [ "natsConnection_GetServers", "group__conn_mgt_group.html#gaf4ee7262e35e44c40ad5dfe9240db76b", null ],
    [ "natsConnection_GetDiscoveredServers", "group__conn_mgt_group.html#gad25c77be0873495412c90a73fe450708", null ],
    [ "natsConnection_GetLastError", "group__conn_mgt_group.html#gab6cfa9cb6857ae10f096a94f5e244e63", null ],
    [ "natsConnection_GetClientID", "group__conn_mgt_group.html#ga747513ba6ab63fdf9a72bfc8025a14ba", null ],
    [ "natsConnection_Drain", "group__conn_mgt_group.html#ga59bdc4ad9fea2053f5d3841f6b83f88b", null ],
    [ "natsConnection_DrainTimeout", "group__conn_mgt_group.html#gae06fe6f5933f216d6d93645a122a7dd4", null ],
    [ "natsConnection_Sign", "group__conn_mgt_group.html#ga6960cfdbaac3b8759784f352d4c264f8", null ],
    [ "natsConnection_GetClientIP", "group__conn_mgt_group.html#gadafcfeeeac2733c7119981ab97b7103d", null ],
    [ "natsConnection_GetRTT", "group__conn_mgt_group.html#gaa3fd27e6e7d8131e679d4f10e201c435", null ],
    [ "natsConnection_HasHeaderSupport", "group__conn_mgt_group.html#gad765b80ae8e1a06a7a942cccf29f042a", null ],
    [ "natsConnection_GetLocalIPAndPort", "group__conn_mgt_group.html#ga761095a42374b4dafa178df7d7652dd5", null ],
    [ "natsConnection_Close", "group__conn_mgt_group.html#ga19e204d27a232e2d4334301fc002b2ed", null ],
    [ "natsConnection_Destroy", "group__conn_mgt_group.html#gafda2f702276fb0ac301efac10df09495", null ],
    [ "natsConnection_Publish", "group__conn_pub_group.html#gac0b9f7759ecc39b8d77807b94254f9b4", null ],
    [ "natsConnection_PublishString", "group__conn_pub_group.html#gad09a717c20de4cf0e2a21dcfd9ce6c64", null ],
    [ "natsConnection_PublishMsg", "group__conn_pub_group.html#ga74511acd87385931112c45c48c2a14ba", null ],
    [ "natsConnection_PublishRequest", "group__conn_pub_group.html#gaaaa3d75ffec2dcdc6bf905cdb1eee59e", null ],
    [ "natsConnection_PublishRequestString", "group__conn_pub_group.html#gaafca9a8294e81a5a9979e762931e56c5", null ],
    [ "natsConnection_Request", "group__conn_pub_group.html#gaf4b4a022f9c21fc269b87c000330c5a7", null ],
    [ "natsConnection_RequestString", "group__conn_pub_group.html#ga4bb5105df6a3efd2088e6be0fdf6b31f", null ],
    [ "natsConnection_RequestMsg", "group__conn_pub_group.html#ga052de4b75b3b69ccd8d20eb4861b801d", null ],
    [ "natsConnection_Subscribe", "group__conn_sub_group.html#gaefab965b5645798d47f9244f2b3fe3fb", null ],
    [ "natsConnection_SubscribeTimeout", "group__conn_sub_group.html#gacb2c83b58b7909715424cbc327fdd404", null ],
    [ "natsConnection_SubscribeSync", "group__conn_sub_group.html#ga17574d5165f7e285462e3d3b2709edf4", null ],
    [ "natsConnection_QueueSubscribe", "group__conn_sub_group.html#ga3c9fee2775130786ef62f1cbeb191a48", null ],
    [ "natsConnection_QueueSubscribeTimeout", "group__conn_sub_group.html#ga96fa115fd5b2ef7658884da80714b91c", null ],
    [ "natsConnection_QueueSubscribeSync", "group__conn_sub_group.html#ga68630ea7c4bbdc7f8cd62058b41fb476", null ],
    [ "natsSubscription_NoDeliveryDelay", "group__sub_group.html#ga38f1e41fc7619101fc4aa52014dd5428", null ],
    [ "natsSubscription_NextMsg", "group__sub_group.html#ga6538a5d78dfb0f16514b94c8e74c11af", null ],
    [ "natsSubscription_Unsubscribe", "group__sub_group.html#gaee87f8be0e6c2a4693ba2cea070583ba", null ],
    [ "natsSubscription_AutoUnsubscribe", "group__sub_group.html#ga09f285de2746a6e27fc66efd60bd3116", null ],
    [ "natsSubscription_QueuedMsgs", "group__sub_group.html#ga8a37b2d5290da3aecc05483d79e7e254", null ],
    [ "natsSubscription_GetID", "group__sub_group.html#ga5a029a784c0a7f8b5800b48cc995db20", null ],
    [ "natsSubscription_GetSubject", "group__sub_group.html#gadd4872b9fc5678a73f9ab04ce8428432", null ],
    [ "natsSubscription_SetPendingLimits", "group__sub_group.html#ga68a7cea89e75c529a7dd3bb77303dda4", null ],
    [ "natsSubscription_GetPendingLimits", "group__sub_group.html#ga786bb458981274fe717f266bd3b96d96", null ],
    [ "natsSubscription_GetPending", "group__sub_group.html#gaca6262e2ef842caa701a9f233db72707", null ],
    [ "natsSubscription_GetDelivered", "group__sub_group.html#ga476b7276d0b7f9946834d2bb2423e955", null ],
    [ "natsSubscription_GetDropped", "group__sub_group.html#ga24f1636869e26661ce62c9c9f4d80823", null ],
    [ "natsSubscription_GetMaxPending", "group__sub_group.html#ga0abc5d9afbc6b0c9c5adaf533904c968", null ],
    [ "natsSubscription_ClearMaxPending", "group__sub_group.html#gafe31911d8372db401d33856465421710", null ],
    [ "natsSubscription_GetStats", "group__sub_group.html#ga12b60cdb3aca7329edebc480ae86bfab", null ],
    [ "natsSubscription_IsValid", "group__sub_group.html#ga5e6454bbc7a90b9694112d45bd8de903", null ],
    [ "natsSubscription_Drain", "group__sub_group.html#ga26c9736289d326fb7d6df7e2a0df72ab", null ],
    [ "natsSubscription_DrainTimeout", "group__sub_group.html#ga9c26a3f9584e7804060a48ec1b7e2a68", null ],
    [ "natsSubscription_WaitForDrainCompletion", "group__sub_group.html#ga0408c9b6e4ad4078ac0267656ace222d", null ],
    [ "natsSubscription_DrainCompletionStatus", "group__sub_group.html#ga9834bd02f67a25ac084d5ad71e146019", null ],
    [ "natsSubscription_SetOnCompleteCB", "group__sub_group.html#gaea632f845d473e7461b134c0e7bf4077", null ],
    [ "natsSubscription_Destroy", "group__sub_group.html#ga50a95dd96e9b714201679a015d62832f", null ],
    [ "stanConnection_Connect", "group__stan_conn_mgt_group.html#ga35e0e6e5e3b7f3818a3ac3600efb8f8f", null ],
    [ "stanConnection_GetNATSConnection", "group__stan_conn_mgt_group.html#ga166ec494a55c9b1f9ebafd2294e05ff6", null ],
    [ "stanConnection_ReleaseNATSConnection", "group__stan_conn_mgt_group.html#ga2e56a93825e1214a5ab688860e2a8ce6", null ],
    [ "stanConnection_Close", "group__stan_conn_mgt_group.html#ga4952a7f65a53fdb5ca1c26b1a1656f1d", null ],
    [ "stanConnection_Destroy", "group__stan_conn_mgt_group.html#gaea095eec18fdf04e06de16711f8b1a04", null ],
    [ "stanConnection_Publish", "group__stan_conn_pub_group.html#ga24f3f7f709b15fe53e1edaeead08fc7d", null ],
    [ "stanConnection_PublishAsync", "group__stan_conn_pub_group.html#ga0c4d1e4615f8ac834f0a4021f75d39f0", null ],
    [ "stanConnection_Subscribe", "group__stan_conn_sub_group.html#gae545358fdc493baf6d29429a8156781f", null ],
    [ "stanConnection_QueueSubscribe", "group__stan_conn_sub_group.html#ga17d42bf9a4fa39470561a1a668e6b4a2", null ],
    [ "stanSubscription_SetOnCompleteCB", "group__stan_sub_group.html#ga7b039908ec45cfc2c16ec61ba8daca9d", null ],
    [ "stanSubscription_AckMsg", "group__stan_sub_group.html#ga3a1cca9fa3ea54fcf7a43fd1335a26d3", null ],
    [ "stanSubscription_Unsubscribe", "group__stan_sub_group.html#gafa428a7e0f6800216cb06fd738bd235e", null ],
    [ "stanSubscription_Close", "group__stan_sub_group.html#gacfa3a7b4fa333c84acfa7521fbbb5bcc", null ],
    [ "stanSubscription_Destroy", "group__stan_sub_group.html#ga3f6ce924f6a1830a55e30e9910aad4ba", null ],
    [ "jsOptions_Init", "group__js_group.html#ga855ff9a04888d696785cc5ede96112e4", null ],
    [ "natsConnection_JetStream", "group__js_group.html#ga8ed08b0fe1074b1e490291f0af2cb03f", null ],
    [ "jsCtx_Destroy", "group__js_group.html#gacfa6ce3e60ea540e3331a09a7f3dc856", null ],
    [ "jsStreamConfig_Init", "group__js_assets_group.html#gac230f71dbdc4d10bc7471d01763881d6", null ],
    [ "jsPlacement_Init", "group__js_assets_group.html#ga223691e6831072a0b8f8103a778293b0", null ],
    [ "jsStreamSource_Init", "group__js_assets_group.html#ga7fe8e0bf98a38eb59372e7cd78aaaf56", null ],
    [ "jsExternalStream_Init", "group__js_assets_group.html#ga81aebebcd79922104720da51e95020d4", null ],
    [ "jsRePublish_Init", "group__js_assets_group.html#ga388bfeaa5a78ebf6ce7c15c6e3a7156b", null ],
    [ "js_AddStream", "group__js_assets_group.html#ga5efc5136d33ba52161e6732f88f1ee75", null ],
    [ "js_UpdateStream", "group__js_assets_group.html#ga75a5c44304e24481c67e17fbccc15c31", null ],
    [ "js_PurgeStream", "group__js_assets_group.html#ga5a6a886c18a79caa403908bf7f7ef125", null ],
    [ "js_DeleteStream", "group__js_assets_group.html#ga397e55a0b3b6d36c9bf746eee3842172", null ],
    [ "js_GetMsg", "group__js_assets_group.html#ga9fe289ae172f83e53ca1b1b747744c1f", null ],
    [ "js_GetLastMsg", "group__js_assets_group.html#ga6835b53da27d5721eddb3698e582cf0c", null ],
    [ "jsDirectGetMsgOptions_Init", "group__js_assets_group.html#ga8d835d47aed9c84ce3b8dcfea469f4cb", null ],
    [ "js_DirectGetMsg", "group__js_assets_group.html#ga62c250cecc650b1eed0fa1691893e2ae", null ],
    [ "js_DeleteMsg", "group__js_assets_group.html#gaeba5d45abbe811c0e40830c5f26c78fd", null ],
    [ "js_EraseMsg", "group__js_assets_group.html#ga7158f73e183462e9a15e9802e1746ff0", null ],
    [ "js_GetStreamInfo", "group__js_assets_group.html#ga94cb23a35516b7779de28fcbb263180a", null ],
    [ "jsStreamInfo_Destroy", "group__js_assets_group.html#ga8ee87ef86e94be42685941abe9638bbd", null ],
    [ "js_Streams", "group__js_assets_group.html#ga531d91de372f0dffb8d64abecf88b0c0", null ],
    [ "jsStreamInfoList_Destroy", "group__js_assets_group.html#ga38cdcc339eb8976d23296b99aa37d629", null ],
    [ "js_StreamNames", "group__js_assets_group.html#gac3dfc87863dbbb3c959ecde4bce905bc", null ],
    [ "jsStreamNamesList_Destroy", "group__js_assets_group.html#gaf8644f281d4e24893a6a170b4f7faa65", null ],
    [ "jsConsumerConfig_Init", "group__js_assets_group.html#ga3381bb05c05bf4a8979adde68d37dd66", null ],
    [ "js_AddConsumer", "group__js_assets_group.html#gaf2efb63db150e782d9007090b49d4115", null ],
    [ "js_UpdateConsumer", "group__js_assets_group.html#gad13ec256e24710bb237995814871e554", null ],
    [ "js_GetConsumerInfo", "group__js_assets_group.html#ga2dda04757b4ab27a794b64f8d727fe23", null ],
    [ "js_DeleteConsumer", "group__js_assets_group.html#ga52fbc61759b11494db91f348a733c490", null ],
    [ "jsConsumerInfo_Destroy", "group__js_assets_group.html#ga9c1d5ed2f24ba836c10e415231f80088", null ],
    [ "js_Consumers", "group__js_assets_group.html#gaf28097ede3e9ba9926fb00856e63ffd9", null ],
    [ "jsConsumerInfoList_Destroy", "group__js_assets_group.html#ga421de40d8e91658353111c3f2ea90ec8", null ],
    [ "js_ConsumerNames", "group__js_assets_group.html#ga690d19af55d12b82c8523d1861cef8d0", null ],
    [ "jsConsumerNamesList_Destroy", "group__js_assets_group.html#ga2ced0d190131460bf4608ab893dffc50", null ],
    [ "js_GetAccountInfo", "group__js_assets_group.html#gac8965dcfc6b465fbc323aa552c606c46", null ],
    [ "jsAccountInfo_Destroy", "group__js_assets_group.html#ga7c8664b38fcce8497746367d35e5f60b", null ],
    [ "jsPubOptions_Init", "group__js_pub_group.html#gaf09f333a8675a8060c5ede07a6bdeef9", null ],
    [ "js_Publish", "group__js_pub_group.html#gac6ba005531c82d9f0efa88dd6b458477", null ],
    [ "js_PublishMsg", "group__js_pub_group.html#ga2aceeb82fac3621aea843dd246732bdd", null ],
    [ "jsPubAck_Destroy", "group__js_pub_group.html#gaac130840b6db9109e72cf6ad9186dfc4", null ],
    [ "js_PublishAsync", "group__js_pub_group.html#ga069dfd6f0f3d96f1ff8bf2372e59900c", null ],
    [ "js_PublishMsgAsync", "group__js_pub_group.html#gab7e4139a48c5ee4d2155cbb43142e873", null ],
    [ "js_PublishAsyncComplete", "group__js_pub_group.html#ga24813ee9a58f00c0f21d10ab9c93b81d", null ],
    [ "js_PublishAsyncGetPendingList", "group__js_pub_group.html#ga2ac95a3450f77f8074fae3f2fbe7e54c", null ],
    [ "jsSubOptions_Init", "group__js_sub_group.html#ga472adb949d1af9d8f07bda99f5d7f3f8", null ],
    [ "js_Subscribe", "group__js_sub_group.html#gaa686c6efd84ef963de1925108e896515", null ],
    [ "js_SubscribeSync", "group__js_sub_group.html#gabacb010031e535f9fb6e2167337e8adf", null ],
    [ "js_PullSubscribe", "group__js_sub_group.html#gaaeaddb73857aa4eb4901eec945ed27cd", null ],
    [ "natsSubscription_Fetch", "group__js_sub_group.html#gafc5e0d2269bd23b4d5fb7f3b05278e50", null ],
    [ "jsFetchRequest_Init", "group__js_sub_group.html#ga1c3a62de8cd4855ae61ea4f67417a43b", null ],
    [ "natsSubscription_FetchRequest", "group__js_sub_group.html#ga676292505e7fde8688cfd886b79a10ed", null ],
    [ "natsSubscription_GetConsumerInfo", "group__js_sub_group.html#gaae716a1431db065744c079b71a9f4c2e", null ],
    [ "natsSubscription_GetSequenceMismatch", "group__js_sub_group.html#ga0daed9f0d2d00cb14314ecc180a6fa84", null ],
    [ "natsMsg_GetMetaData", "group__js_msg.html#gacf48e59038fab35849e9dc6f8fcf6328", null ],
    [ "jsMsgMetaData_Destroy", "group__js_msg.html#gaf9bf92294342bcb27053de7038606d12", null ],
    [ "natsMsg_Ack", "group__js_msg.html#gae454fb7e7097a3cd3362cb49ef8a3c84", null ],
    [ "natsMsg_AckSync", "group__js_msg.html#gafb899ebf8e89b3a858fe20f7853635a7", null ],
    [ "natsMsg_Nak", "group__js_msg.html#gac271b874154301da9759f9ac05768b47", null ],
    [ "natsMsg_NakWithDelay", "group__js_msg.html#gac0697389fa60a3c4725e53cd23ada7bd", null ],
    [ "natsMsg_InProgress", "group__js_msg.html#gae1e0beb19cd76e2f69e6415c41c9bb39", null ],
    [ "natsMsg_Term", "group__js_msg.html#gae84d21e4388255e9d990e53c9f67e7c4", null ],
    [ "natsMsg_GetSequence", "group__js_msg.html#ga819be2990ec20b964aa574b5331d7f2e", null ],
    [ "natsMsg_GetTime", "group__js_msg.html#gab4850497c5481f5ec6eb1fcdb43646f5", null ],
    [ "kvConfig_Init", "group__kv_group_mgt.html#ga16d4c27d8ac62bb86ba601bc40f53172", null ],
    [ "js_CreateKeyValue", "group__kv_group_mgt.html#gabc445bfe87112e56a6c73872fec6893e", null ],
    [ "js_KeyValue", "group__kv_group_mgt.html#ga54e6c109a7c633e431b3eded286e00f6", null ],
    [ "js_DeleteKeyValue", "group__kv_group_mgt.html#ga6bc715319560bc28359679fcdcead937", null ],
    [ "kvStore_Destroy", "group__kv_group_mgt.html#gab0d6bdbfabd27af67eaeb36cec0787da", null ],
    [ "kvEntry_Bucket", "group__kv_entry.html#gadedbb410cce499afb535eb6641c32ca7", null ],
    [ "kvEntry_Key", "group__kv_entry.html#gab455f32b0abfb1361dab4b5e7d98042a", null ],
    [ "kvEntry_Value", "group__kv_entry.html#ga28077f81d71a30cbce2dc81e5c9574fc", null ],
    [ "kvEntry_ValueLen", "group__kv_entry.html#gaf7ccc866865903f231e0431754ed2415", null ],
    [ "kvEntry_ValueString", "group__kv_entry.html#ga7ff6220915726600545357e31226fb65", null ],
    [ "kvEntry_Revision", "group__kv_entry.html#ga2d58abf81cb577e21a76f9c77568409f", null ],
    [ "kvEntry_Created", "group__kv_entry.html#ga31ef3a2e3a7df6cf4dbb0a762737800a", null ],
    [ "kvEntry_Delta", "group__kv_entry.html#ga233a2d75895cfd0140cf77757592cf47", null ],
    [ "kvEntry_Operation", "group__kv_entry.html#ga088fd67d3d384ad7a7ddfc82535becea", null ],
    [ "kvEntry_Destroy", "group__kv_entry.html#ga8359ffcdeefb9c5821e6442d0d5ee388", null ],
    [ "kvStore_Get", "group__kv_group.html#ga2db86f80d6bfce1bdbedf1b9da22913c", null ],
    [ "kvStore_GetRevision", "group__kv_group.html#ga9bf43431bb8264a3ea1f0df401afbe1a", null ],
    [ "kvStore_Put", "group__kv_group.html#ga1fdf7a1d3acf96e475184790589a401e", null ],
    [ "kvStore_PutString", "group__kv_group.html#ga84ebd66a95ce857765d4a16ec35daba9", null ],
    [ "kvStore_Create", "group__kv_group.html#ga5289f7cd3999cfb46fb1fcb83178aec6", null ],
    [ "kvStore_CreateString", "group__kv_group.html#ga5726ad2e6205d2f6749be013138218ca", null ],
    [ "kvStore_Update", "group__kv_group.html#gae0c593bb2ef94ae60e775617c9423038", null ],
    [ "kvStore_UpdateString", "group__kv_group.html#ga13ed70f15cd1485cd15f96bcc4b7ad1c", null ],
    [ "kvStore_Delete", "group__kv_group.html#ga68101d46739ca894fd7c56c8661c08d8", null ],
    [ "kvStore_Purge", "group__kv_group.html#ga3d5fa3d895d0d3041440105b244e9ca9", null ],
    [ "kvWatchOptions_Init", "group__kv_group.html#ga762fd5de8cde683e46a6736a51e575f5", null ],
    [ "kvPurgeOptions_Init", "group__kv_group.html#ga243113fd7df34ce104850ab888f04021", null ],
    [ "kvStore_PurgeDeletes", "group__kv_group.html#ga34ab74b229ff88e64301ea53a274da69", null ],
    [ "kvStore_Watch", "group__kv_group.html#ga30feca870f580c7b9d2ad07a740505b2", null ],
    [ "kvStore_WatchAll", "group__kv_group.html#gaf011f1dd6813391c65664e982747602e", null ],
    [ "kvStore_Keys", "group__kv_group.html#ga6030fc2a672ae868f7603587245b9d5a", null ],
    [ "kvKeysList_Destroy", "group__kv_group.html#ga02ccd58bc5062f6ce6f94bf05e3dfe45", null ],
    [ "kvStore_History", "group__kv_group.html#ga5aa57345313cee85b020e50c22023fb5", null ],
    [ "kvEntryList_Destroy", "group__kv_group.html#gae783352ab81e22aa3173057d117518e6", null ],
    [ "kvStore_Bucket", "group__kv_group.html#gad28fdf9aae16bba308cda799fca13281", null ],
    [ "kvStore_Status", "group__kv_group.html#gadf75e99cc28bc9c2d6eac7c9f7398c27", null ],
    [ "kvWatcher_Next", "group__kv_watcher.html#ga562c216a0199c30455af4c2da46000e5", null ],
    [ "kvWatcher_Stop", "group__kv_watcher.html#ga73adf44114fedd62ef75ebd81839b65e", null ],
    [ "kvWatcher_Destroy", "group__kv_watcher.html#ga21bc39fa795f7c4f392bd6d4e66ea1d9", null ],
    [ "kvStatus_Bucket", "group__kv_status.html#ga1acec36db32207f21e15afc26bb5af1c", null ],
    [ "kvStatus_Values", "group__kv_status.html#ga2016af3c73841d8b226361e764dce158", null ],
    [ "kvStatus_History", "group__kv_status.html#gada6f22b5659b184762cea4f45d369ee5", null ],
    [ "kvStatus_TTL", "group__kv_status.html#gaa747ad0a6182ec7a47fb47018c33d1c1", null ],
    [ "kvStatus_Replicas", "group__kv_status.html#ga86b114f4dac9f06df86101f84bd497b2", null ],
    [ "kvStatus_Destroy", "group__kv_status.html#ga5eb3d824c1873af705beee4798246a08", null ]
];